@@ -18,7 +18,7 @@
 #include "../pen_gesture/login_screen.h"
 
 
-#define SKIP_LOGIN 1
+#define SKIP_LOGIN 0
 static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 	ClutterActor* actor;
 
@@ -26,7 +26,7 @@ static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 		tangle_actor_hide_animated(TANGLE_ACTOR(actor));
 	}
 
-	#ifndef SKIP_LOGIN
+	#if SKIP_LOGIN==0
 	login_screen();
 	#else
 	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
