@@ -16,11 +16,14 @@
 #include "../file_helper.h"
 #include "sequencer.h"
 
+#define DURATION_OF_LONG_CLICK 1000 // milliseconds 1500
 static gboolean renaming_loop = FALSE;
 
+
 //Long click:  rename the item
 void song_on_held_function(TangleButton* button, gpointer user_data) {
 	ClutterActor* actor=CLUTTER_ACTOR(button);
+
 	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
 
 	const char* filename = clutter_actor_get_name(actor);
@@ -37,6 +40,7 @@ void song_on_held_function(TangleButton* button, gpointer user_data) {
 	rename_loop(actor, type);
 }
 
+
 //Short click: play
 void song_on_clicked_function(TangleButton* button, gpointer user_data) {
 
@@ -67,9 +71,13 @@ void song_on_clicked_function(TangleButton* button, gpointer user_data) {
 }
 
 
-
-
-
+/**
+ * Renames song/project and song's labelfile in list and in hard-drive
+ * 
+ * parameters:
+ * -loopName is clutter actor holding the filename
+ * -type: 0=finished song, 1=project
+**/
 void rename_loop(ClutterActor *loopName, int type){
 
 	static gboolean firstCall = TRUE;
@@ -78,7 +86,7 @@ void rename_loop(ClutterActor *loopName, int type){
 	const char* givenname = clutter_text_get_text(CLUTTER_TEXT(text));
 	const char* filename = clutter_actor_get_name(loopName);
 	gchar * newpath = NULL;
-	int i = 0, j = 0, type_length = 0, path_length = 0;
+	int i = 0, j = 0, type_length = 0, path_length = 0, userid_length = 10;
 	int length = strlen(filename);
 	char temp[length];
 	char oldpath[length];
@@ -93,7 +101,7 @@ void rename_loop(ClutterActor *loopName, int type){
 		type_length = 4; //.ogg
 	}
 		
-	for(i = path_length + 1; i < length-type_length; i++){
+	for(i = path_length + 1; i < (length-(type_length + userid_length)); i++){
 		oldpath[j] = temp[i];
 		j++;
 	}
@@ -102,7 +110,7 @@ void rename_loop(ClutterActor *loopName, int type){
 	gchar * path = NULL;
 
 	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
-			gems_profile_manager_get_userid(NULL), oldpath);
+			/*gems_profile_manager_get_userid(NULL)*/TEST_USERID, oldpath);
 
 	if(firstCall == TRUE){
 		firstCall = FALSE;
@@ -122,31 +130,35 @@ void rename_loop(ClutterActor *loopName, int type){
 		if(type == 0){
 
 			const char* projects = configure_get_projects_directory();
-			gchar* new_projects_name = g_strdup_printf("%s/%s.json",projects,givenname);
+			gchar* new_projects_name = g_strdup_printf("%s/%s_%d.json",projects,givenname,/*gems_profile_manager_get_userid(NULL)*/TEST_USERID);
+			
+			if(!file_exist(new_projects_name)){ //if file with same name exists we don't rename
 
-
-			if(file_exist(path)){ //labelfile exists
-				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
-							gems_profile_manager_get_userid(NULL), givenname);
-
-				rename(path, newpath);
+				if(file_exist(path)){ //labelfile exists
+					newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
+								/*gems_profile_manager_get_userid(NULL)*/TEST_USERID, givenname);
+					rename(path, newpath);
+				}
+				rename(filename, new_projects_name);
+				clutter_actor_set_name(loopName, new_projects_name);			
 			}
-			rename(filename, new_projects_name);
-			clutter_actor_set_name(loopName, new_projects_name);
 			g_free(new_projects_name);
+
 		}else if(type == 1){
 
 			const char *finalized = configure_get_finalized_directory();
-			gchar* newname = g_strdup_printf("%s/%s.ogg",finalized,givenname);
+			gchar* newname = g_strdup_printf("%s/%s_%d.ogg",finalized,givenname,/*gems_profile_manager_get_userid(NULL)*/TEST_USERID);
 
-			if(file_exist(path)){ //labelfile exists
-				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
-							gems_profile_manager_get_userid(NULL), givenname);
+			if(!file_exist(newname)){ //if file with same name exists we don't rename
 
-				rename(path, newpath);
+				if(file_exist(path)){ //labelfile exists
+					newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
+								/*gems_profile_manager_get_userid(NULL)*/TEST_USERID, givenname);
+					rename(path, newpath);
+				}
+				rename(filename, newname);
+				clutter_actor_set_name(loopName, newname);
 			}
-			rename(filename, newname);
-			clutter_actor_set_name(loopName, newname);
 			g_free(newname);
 		}
 		renaming_loop = FALSE;
@@ -155,10 +167,17 @@ void rename_loop(ClutterActor *loopName, int type){
 	g_free(newpath);
 }
 
+/**
+ * Plays selected song. 
+ * 
+ * parameters:
+ * -actor is clutter actor holding the filename
+**/
 void play_selected_loop(ClutterActor *actor){
 	
 	static JammoSample *sample = NULL;
 	const char *filename = clutter_actor_get_name(actor);
+	printf("play loop %s\n", filename);
 
 	if(sample == NULL){
 
@@ -182,7 +201,9 @@ void play_selected_loop(ClutterActor *actor){
 	}
 }
 
-
+/**
+ * Reads label information from labelfile given as parameter, and shows the label viewer
+**/
 void show_song_label(show_label_params *params){
 
 	cem_add_to_log("Starting record label view.", J_LOG_DEBUG);
@@ -236,6 +257,9 @@ void show_song_label(show_label_params *params){
 		
 }
 
+/**
+ * Changes view from label viewer to parent view
+**/
 void hide_song_label(gchar* parentview){
 	
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("record-label-viewer")));
@@ -269,7 +293,10 @@ time_type get_current_time(){
 }
 
 /*
- * Function for checking whether file exists.
+ * Function for checking whether file exists or not.
+ * 
+ * parameters:
+ * -filename is the fullpath of the file
  */
 gboolean file_exist(gchar *filename) 
 {
@@ -287,14 +314,90 @@ gboolean file_exist(gchar *filename)
   	}
 }
 
+/**
+ * Builds filename from fullpath. Useful for parsing songname from filepath. Returns filename. 
+ * 
+ * parameters:
+ * -filename is a char pointer where the resulting filename will be saved to
+ * -folder_path is folderpath where the file resides 
+ * -filepath is the fullpath where the filename is parsed from
+**/
+gchar* build_filename(gchar* filepath, gchar* folder_path, gchar* filename, int n)
+{
+	int i = 0, j = 0;
+	int folder_path_length = strlen(folder_path);
+	int filepath_length = strlen(filepath);
+	char temp[filepath_length];
+	char str[filepath_length];
+	
+	strcpy(temp, filepath);
 
-/*
-* Function clears container that may contain other containers.
-*
-* parameters:
-* -listToClear is the container to be cleared
-*
-*/
+	for(i = folder_path_length; i < (filepath_length - n); i++)
+	{
+		str[j] = temp[i];
+		j++;
+	}
+	str[j] = '\0';
+	
+	filename = malloc(strlen((str)+1)* sizeof(gchar));
+	strcpy(filename, str);
+	
+	return filename;	
+}
+
+/**
+ * Builds filepath for specific file. Returns full filepath. 
+ * 
+ * parameters:
+ * -filename is the name of the file
+ * -folder_path is folderpath where the file resides 
+ * -filepath is a char pointer where the resulting fullpath will be saved to
+**/
+gchar* build_filepath(gchar* filename, gchar* folder_path, gchar* filepath)
+{
+	int folder_path_length = strlen(folder_path);
+	int filename_length = strlen(filename);
+	int filepath_length = (folder_path_length + filename_length + 1);
+	
+	char str[filepath_length];
+  	strcpy(str,folder_path);
+  	strcat(str,filename);
+
+	filepath = malloc(strlen((str)+1)*sizeof(char));
+	strcpy(filepath, str);
+		
+	return filepath;
+}
+
+/**
+ * Deletes all files inside jammo temp directory. This should be called before jammo is terminated.  
+**/
+gboolean clear_community_temp_directory(){
+
+	//NOTE: This should be called before jammo is terminated so that temp files will be removed from hard-drive.
+	
+	gchar* command = g_strdup_printf("rm -f %s/*.*",configure_get_temp_directory());
+	gboolean returnvalue = FALSE;
+
+	if(system(command) != 0){
+    		cem_add_to_log("Error clearing jammo temp director", J_LOG_ERROR);
+		returnvalue = FALSE;
+		
+	}else{
+  		cem_add_to_log("Jammo temp directory was sucessfully cleared", J_LOG_ERROR);
+		returnvalue = TRUE;
+	}
+	g_free(command);
+	return returnvalue;
+}
+
+
+/**
+ * Function clears container that may contain other containers.
+ *
+ * parameters:
+ * -listToClear is the container to be cleared
+**/
 void clear_container(ClutterContainer *listToClear){
 	
 	int i = 0;
@@ -320,24 +423,20 @@ void clear_container(ClutterContainer *listToClear){
 		}
 
 	}
-	
-
 	listToClear = 0;	
 
 }
 
-/*
-* Function creates buttons from each .png type file in the directory.
-* 
-* parameters:
-* -path is the path of the directory
-* -list is a container where the buttons are added
-* -funtion is a pointer to a function which handles button press events
-* -width is the width of the button
-* -height is the height of the button
-*
-*/
-
+/**
+ * Function creates buttons from each .png type file in the directory.
+ * 
+ * parameters:
+ * -path is the path of the directory
+ * -list is a container where the buttons are added
+ * -funtion is a pointer to a function which handles button press events
+ * -width is the width of the button
+ * -height is the height of the button
+**/
 gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCallback function, int width, int height){
 		
 	ClutterActor *button = 0;
@@ -355,22 +454,19 @@ gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCa
 	}
 	
   	return TRUE;
-
 }	
 
-/*
-* Function creates and adds a single button into container.
-*
-*parameters:
-* -button is null pointer to a button to be created
-* -list is a container where button is added
-* -path is a path to image of the button
-* -width is the width of the button
-* -height is the height of the button
-* -funtion is a pointer to a function which handles button press events
-*
-*/
-
+/**
+ * Function creates and adds a single button into container.
+ *
+ * parameters:
+ * -button is null pointer to a button to be created
+ * -list is a container where button is added
+ * -path is a path to image of the button
+ * -width is the width of the button
+ * -height is the height of the button
+ * -funtion is a pointer to a function which handles button press events
+**/
 gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* path, int width,int height, GCallback function){
 
 	button = tangle_button_new_with_background_actor(tangle_texture_new(path));
@@ -382,19 +478,17 @@ gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* p
 	return TRUE;
 }
 
-
-/*
-* A callback funtion that limits the line count of editable textfield.
-*
-*parameters:
-*-pointer to a textfield structure
-*
-*/
+/**
+ * A callback funtion that limits the line count of editable textfield.
+ *
+ * parameters:
+ * -pointer to a textfield structure that contains info about how to limit line count etc.
+**/
 void limit_line_count(TextField *text){
 
 	gchar *textField = malloc((text->max_characters+1) * sizeof(gchar));
 	PangoLayout *layout;
-	int index;
+	int line_index;
 	
 	strncpy(textField, clutter_text_get_text(CLUTTER_TEXT(text->text)), text->max_characters);
 	textField[text->max_characters+1] = 0;
@@ -402,15 +496,15 @@ void limit_line_count(TextField *text){
 	layout = clutter_text_get_layout(CLUTTER_TEXT(text->text));
 
 	while(pango_layout_get_line_count(layout) > text->lineCount){
-			index = clutter_text_get_cursor_position(CLUTTER_TEXT(text->text));
+			line_index = clutter_text_get_cursor_position(CLUTTER_TEXT(text->text));
 
-			if(index == -1){
+			if(line_index == -1){
 				textField[strlen(textField)-1] = 0;
 			}else{
-				textField[index] = 0;
-				strcat(textField, textField+index+1);
+				textField[line_index] = 0;
+				strcat(textField, textField + line_index + 1);
 				
-				clutter_text_set_cursor_position(CLUTTER_TEXT(text->text), index == 0 ? 0 : index-1);
+				clutter_text_set_cursor_position(CLUTTER_TEXT(text->text), line_index == 0 ? 0 : line_index-1);
 			}
 			
 			g_signal_handler_disconnect(text->text, text->handler_id);
@@ -423,21 +517,18 @@ void limit_line_count(TextField *text){
 		
 }
 
+/**
+ * Frees dynamically allocated memory from GList that contains pointers to message structures.
+**/
+void clear_messagelist(GList* messages_){
 
+	messages_ = g_list_first(messages_);
 
-/*
-* Frees dynamically allocated memory from GList that contains pointers to message structures.
-*/
+	message_type *temp = 0;
 
-void clear_messagelist(GList* messages){
-
-	messages = g_list_first(messages);
-
-	message *temp = 0;
-
-	if(messages != NULL){
+	if(messages_ != NULL){
 		
-		temp = messages->data;
+		temp = messages_->data;
 
 		if(temp->msg != NULL)
 			free(temp->msg);
@@ -445,14 +536,14 @@ void clear_messagelist(GList* messages){
 		if(temp->filepath != NULL)
 			free(temp->filepath);
 
-		if(messages->data != NULL)
-			free(messages->data);
+		if(messages_->data != NULL)
+			free(messages_->data);
 	
-		while(messages->next != NULL)
+		while(messages_->next != NULL)
 		{
-			messages = messages->next;
+			messages_ = messages_->next;
 				
-			temp = messages->data;
+			temp = messages_->data;
 
 			if(temp->msg != NULL)
 				free(temp->msg);				
@@ -460,24 +551,88 @@ void clear_messagelist(GList* messages){
 			if(temp->filepath != NULL)
 				free(temp->filepath);				
 				
-			if(messages->data != NULL)
-				free(messages->data);				
+			if(messages_->data != NULL)
+				free(messages_->data);				
 		}
+	g_list_free(messages_);
+	
+	messages_ = NULL;
 	
 	}
-
-
-
 }
 
-/*
-* Computes the avatar from guint32 type number.
-*
-*paramters:
-* -avatar is pointer to a Avatar struct, where the avatar will be created.
-* -avatar_id tells the avatar type.
-*/
 
+/**
+ * Frees dynamically allocated memory from GList that contains pointers to song_type structures.
+**/
+void clear_songlist(GList* songs){
+
+	songs = g_list_first(songs);
+
+	song_type *temp = 0;
+
+	if(songs != NULL)
+	{
+		temp = songs->data;
+
+		if(temp->songid != NULL)
+			free(temp->songid);
+			
+		if(temp->filename != NULL)
+			free(temp->filename);
+
+		if(temp->cover != NULL)
+			free(temp->cover);
+			
+		if(temp->comments_path != NULL)
+			free(temp->comments_path);
+
+		if(songs->data != NULL)
+			free(songs->data);
+	
+		while(songs->next != NULL)
+		{
+			songs = songs->next;
+				
+			temp = songs->data;
+
+			if(temp->songid != NULL)
+			free(temp->songid);
+			
+			if(temp->filename != NULL)
+				free(temp->filename);
+
+			if(temp->cover != NULL)
+				free(temp->cover);
+			
+			if(temp->comments_path != NULL)
+				free(temp->comments_path);
+
+			if(songs->data != NULL)
+				free(songs->data);				
+		}
+		g_list_free(songs);
+		songs = NULL;
+	}
+}
+
+
+/**
+ * Computes the avatar from guint32 type number.
+ *
+ * Avatar is serialized in 32 bits in the following way:
+ * 		-head id is the 4 least significant bits (bits 0-3)
+ *		-hair color is bits 4-7
+ *		-body is bits 8-15
+ *		-hair type is bits 16-23 
+ *		-instrument is in bits 24-31
+ *
+ *	Note that ids are actually index numbers of avatar parts. Parts are arranged in alphabetical order.
+ *
+ * parameters:
+ * -avatar is pointer to a Avatar struct, where the avatar will be created.
+ * -avatar_id tells the avatar type.
+**/
 gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 
 	int head, hair_color, hair_type, body, instrument;
@@ -502,7 +657,6 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		community_open_and_arrange_dir(path, ".png", result);
 		avatar->head = tangle_texture_new(strcat(path, result[head-1]));	
 		clutter_actor_set_name(avatar->head, path);
-	
 	}
 
 	if(body != 0){
@@ -512,7 +666,6 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		community_open_and_arrange_dir(path, ".png", result);
 		avatar->body = tangle_texture_new(strcat(path, result[body-1]));	
 		clutter_actor_set_name(avatar->body, path);
-	
 	}
 	
 	if(hair_color != 0 && hair_type != 0){
@@ -530,8 +683,6 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		
 		avatar->hair = tangle_texture_new(path);
 		clutter_actor_set_name(avatar->hair, path);
-		
-	
 	}	
 	
 	if(instrument != 0){
@@ -539,8 +690,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		strcpy(path, instruments_path);
 		community_open_and_arrange_dir(path, ".png", result);
 		avatar->instrument = tangle_texture_new(strcat(path, result[instrument-1]));
-		clutter_actor_set_name(avatar->instrument, path);
-	
+		clutter_actor_set_name(avatar->instrument, path);	
 	
 	}
 	g_free(heads_path);
@@ -549,17 +699,25 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 	g_free(instruments_path);
 
 	return TRUE;
-
 }
 
-/*
-* Computes and saves guint32 type number from user avatar
-*
-*paramters:
-* -avatar is pointer to a Avatar struct, which contains user avatar
-*/
-
-gboolean community_save_avatar(Avatar* avatar){
+/**
+ * Computes and saves guint32 type number from user avatar.
+ *
+ * Avatar is serialized in 32 bits in the following way:
+ * 		-head id is the 4 least significant bits (bits 0-3)
+ *		-hair color is bits 4-7
+ *		-body is bits 8-15
+ *		-hair type is bits 16-23 
+ *		-instrument is in bits 24-31
+ *
+ *	Note that ids are actually index numbers of avatar parts. Parts are arranged in alphabetical order.
+ *
+ * parameters:
+ * -avatar is pointer to a Avatar struct, which contains user avatar
+ * returns: avatar id in guint32
+**/
+guint32 community_save_avatar(Avatar* avatar){
 
 	guint32 head = 0, hair_color = 0, hair_type = 0, body = 0, instrument = 0;
 	char path[150];
@@ -651,25 +809,26 @@ gboolean community_save_avatar(Avatar* avatar){
 	g_free(bodys_path);
 	g_free(hairs_path);
 	g_free(instruments_path);
+
+	gems_profile_manager_set_avatar_id(id);
 	
-	return gems_profile_manager_set_avatar_id(id);
+	return id;
 
 }
 
 
-/*
-* This function opens directory, and sorts files in alphabetical order.
-* Files must be sorted because file order from opendir() may be different in each device.
-*
-*parameters: 
-* -path is full path of directory to be opened
-* -suffix defines which type files will be sorted, other files are ignored
-*   (if suffix is "DIR", only directories are listed)
-* -result is an array of strings that contains filenames in order when this funtion returns
-*
-* returns number of files found
-*/
-
+/**
+ * This function opens directory, and sorts files in alphabetical order.
+ * Files must be sorted because file order from opendir() may be different in each device.
+ *
+ * parameters: 
+ * -path is full path of directory to be opened
+ * -suffix defines which type of files will be sorted, other files are ignored
+ *   (if suffix is "DIR", only directories are listed)
+ * -result is an array of strings that contains filenames in order when this funtion returns
+ *
+ * returns number of files found
+**/
 int community_open_and_arrange_dir(const char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
 	
 	DIR *dir;
@@ -686,43 +845,35 @@ int community_open_and_arrange_dir(const char* path, char* suffix, char result[M
 				if(strstr(dir_ent->d_name, ".") != 0 || strstr(dir_ent->d_name, "..") != 0)
 					numberOfFiles--;
 
-			
 				else strcpy(result[numberOfFiles], dir_ent->d_name);
 
 			}
 		
 		}else{
-	
 			for(numberOfFiles = 0; (dir_ent = readdir(dir)) != 0; numberOfFiles++){
 			
 				if(strstr(dir_ent->d_name, suffix) == 0)
 					numberOfFiles--;
-
 			
 				else	strcpy(result[numberOfFiles], dir_ent->d_name);	
 
 			}
 		}
-	
 		qsort(result, numberOfFiles, MAX_FILE_NAME_LEN, (void*)strcoll);
 	
-		
 		closedir(dir);
-		
 	}
-
 	return numberOfFiles;
 
 }
 
-/*
-* Transforms avatar into smaller scale, so it can be used in thread-views.
-*
-*parameters:
-* -avatar is the avatar to be scaled
-* -avatarBackground is container, where avatar will be set
-*/
-
+/**
+ * Transforms avatar into smaller scale, so it can be used in thread-views.
+ *
+ * parameters:
+ * -avatar is the avatar to be scaled
+ * -avatarBackground is container, where avatar will be set
+**/
 void community_shrink_and_set_avatar(Avatar* avatar, ClutterContainer *avatarBackground){
 
 	gfloat width, height;
@@ -778,7 +929,6 @@ void community_shrink_and_set_avatar(Avatar* avatar, ClutterContainer *avatarBac
 		if(strstr(clutter_actor_get_name(avatar->hair), "hair_top.png"))	
 			clutter_actor_set_position(avatar->hair, 15, 8);		
 	
-	
 	}
 	
 	if(avatar->head != 0)
@@ -792,11 +942,9 @@ void community_shrink_and_set_avatar(Avatar* avatar, ClutterContainer *avatarBac
 
 }
 
-/*
-* Funtion frees GList that contains pointers to dynamically allocated profile_view_params structures
-*/
-
-
+/**
+ * Funtion frees GList that contains pointers to dynamically allocated profile_view_params structures
+**/
 void community_clear_paramslist(GList* paramsList){
 
 	paramsList = g_list_first(paramsList);
@@ -819,11 +967,9 @@ void community_clear_paramslist(GList* paramsList){
 
 }
 
-/*
-* Funtion frees GList that contains pointers to dynamically allocated show_label_params structures
-*/
-
-
+/**
+ * Funtion frees GList that contains pointers to dynamically allocated show_label_params structures
+**/
 void community_clear_labelparamslist(GList* paramslist){
 
 	paramslist = g_list_first(paramslist);
@@ -839,12 +985,12 @@ void community_clear_labelparamslist(GList* paramslist){
 			g_free(paramslist->data);
 		}   
 	}
-	
 	g_list_free(paramslist);
-
 }
 
-
+/**
+ * Scrolls the list to correct position automatically
+**/
 void community_autoscroll_to_correct_pos(list_type *list)
 {
 	gint slot;
@@ -859,3 +1005,221 @@ void community_autoscroll_to_correct_pos(list_type *list)
 
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*list->listItemHeight), NULL);
 }
+
+
+/**
+ * Downloads a specific file from server
+**/
+gboolean load_file_from_server(gchar * filename) 
+{	
+	gboolean returnvalue = TRUE;
+	
+	//TODO: download json from server and check that the file was received
+		
+	return returnvalue;
+}
+
+/**
+ * Loads songs/loops from json file. Note that this function allocates memory which should be freed later. 
+ *
+ * parameters:
+ * -filename is name of the json file
+ * -list is a pointer pointing to GList where songs/loops will be saved to
+ * -type: 0=loop, 1=song
+**/
+gboolean parse_songs_from_file(gchar* filename, GList** list, int type) 
+{	
+	int j;
+	JsonParser *parser;
+	JsonNode *root;
+	JsonObject *object;
+	JsonNode *node;
+
+	song_type *song = 0;
+	loop_type *loop = 0;
+	
+	//Init JSON Parser
+	parser = json_parser_new();
+	g_assert (JSON_IS_PARSER(parser));
+	GError *error = NULL;
+	
+	//Load file
+	if (!json_parser_load_from_file (parser, filename, &error)){ 
+		g_print ("Error: %s\n", error->message);
+		g_error_free (error);
+		g_object_unref (parser);
+		return FALSE;
+	}
+
+	if(json_parser_get_root(parser) != NULL){
+		root = json_parser_get_root (parser);
+	}else{
+		return FALSE;
+	}
+	if(JSON_NODE_TYPE(root) != JSON_NODE_OBJECT)
+		return FALSE;
+
+	object = json_node_get_object (root);
+	if(object == NULL)
+		return FALSE;
+	
+	//Fill array with tracks
+	JsonArray* track_array;
+	guint length_tracks = 0;
+	node = json_object_get_member (object, "tracks");
+	
+	if (node != NULL && JSON_NODE_TYPE (node) == JSON_NODE_ARRAY){
+		track_array =  json_node_get_array (node);
+		length_tracks = json_array_get_length(track_array);
+		printf("Found %d tracks\n", length_tracks);
+	}else {
+		printf("No tracks found\n"); 
+		return TRUE;
+	}
+	
+	//Check track properties
+	for (j = 0; j < length_tracks; j++) {
+
+		JsonNode* track_node;
+		track_node = json_array_get_element(track_array, j);
+
+		if (track_node != NULL && (JSON_NODE_TYPE(track_node) == JSON_NODE_OBJECT)){
+			
+			JsonObject* sub_object = json_node_get_object(track_node);
+			JsonNode *sub_node;
+			
+			gchar* id = "";
+			gchar* name=  "";
+			guint32 userid = 0; 
+			gchar* track_filename =  "";
+			//gchar* info_filename = "";
+			gchar* label =  "";
+			gchar* comments =  "";
+			gchar* date =  "";
+
+			printf("\nFound track!\n");
+
+			if(type == 1){ //songs
+			
+				sub_node = json_object_get_member(sub_object, "songid"); 
+				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+					id = (gchar*)json_node_get_string(sub_node);
+					printf("songid: '%s'\n", id);
+				}		
+				sub_node = json_object_get_member(sub_object, "songname");
+			
+				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+					name = json_node_get_string(sub_node);
+					printf("songname: '%s'\n", name);
+				}
+
+			}else if (type == 0){ //loops
+
+				sub_node = json_object_get_member(sub_object, "loopid"); 
+				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+					id = (gchar*)json_node_get_string(sub_node);
+					printf("loopid: '%s'\n", id);
+				}		
+				sub_node = json_object_get_member(sub_object, "loopname");
+			
+				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+					name = json_node_get_string(sub_node);
+					printf("loopname: '%s'\n", name);
+				}
+
+			}
+			sub_node = json_object_get_member(sub_object, "userid"); 
+			
+			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+				userid = (guint32)atoi(json_node_get_string(sub_node));			
+				printf("userid: '%d'\n", userid);
+			}		
+			sub_node = json_object_get_member(sub_object, "filename");
+			
+			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+				track_filename = json_node_get_string(sub_node);
+				printf("filename: '%s'\n", track_filename);
+			}		
+			/*sub_node = json_object_get_member(sub_object, "info"); 
+			
+			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+				info_filename = (gchar*)json_node_get_string(sub_node);
+				printf("info-file: '%s'\n", info_filename);
+			}*/
+
+			if(type == 1){ //songs	
+	
+				sub_node = json_object_get_member(sub_object, "cover");
+			
+				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+					label = json_node_get_string(sub_node);
+					printf("cover path: '%s'\n", label);
+				}
+				sub_node = json_object_get_member(sub_object, "comments"); 
+			
+				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+					comments = (gchar*)json_node_get_string(sub_node);
+					printf("comments path: '%s'\n", comments);
+				}
+			}
+			
+			sub_node = json_object_get_member(sub_object, "date");
+			
+			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
+				date = json_node_get_string(sub_node);
+				printf("date: '%s'\n", date);
+			}
+
+			//Save information into struct
+
+			if(type == 1){ //songs
+
+				song = malloc(sizeof (song_type));
+
+				strcpy(song->songname, name);
+				song->user_id = userid;	
+				strcpy(song->date, date);
+			
+				song->songid = malloc((strlen(id)+1)*sizeof(gchar));
+				strcpy(song->songid, id);	
+				song->filename = malloc((strlen(track_filename)+1)*sizeof(gchar));
+				strcpy(song->filename, track_filename);
+				//song->json = malloc(strlen(info_filename)+sizeof(gchar));
+				//strcpy(song->json, info_filename);
+				song->cover = malloc((strlen(label)+1)*sizeof(gchar));
+				strcpy(song->cover, label);
+				song->comments_path = malloc((strlen(comments)+1)*sizeof(gchar));
+				strcpy(song->comments_path, comments);	
+
+			}else if (type == 0){ //loops
+
+				loop = malloc(sizeof(loop_type));
+
+				strcpy(loop->loopname, name);
+				loop->user_id = userid;	
+				strcpy(loop->date, date);
+			
+				loop->loopid = malloc((strlen(id)+1)*sizeof(gchar));
+				strcpy(loop->loopid, id);	
+				loop->filename = malloc((strlen(track_filename)+1)+sizeof(gchar));
+				strcpy(loop->filename, track_filename);
+
+			}
+			
+		} //Track is ready
+		
+		//Save struct into global array
+		
+		if(type == 1){
+		 	*list = g_list_append((GList*)*list, (gpointer)song);
+		}else if(type == 0){
+			*list = g_list_append((GList*)*list, (gpointer)loop);
+		}
+
+	} //Next track
+
+	printf("\n");
+	g_object_unref(parser);
+	
+	return TRUE;
+}
