@@ -400,12 +400,12 @@ void pg_set_msg_from_image(ClutterActor *stage, gchar *filename, int pos_x, int
 		//FIXME: this is never free'ed.
 	  gchar* path1 = g_build_filename (pg_directory_path, filename, NULL);
 		//FIXME: this is never free'ed.
-	  ClutterActor *message = tangle_texture_new (path1);
-	  clutter_actor_set_size (message, 200, 100);
-	  clutter_actor_set_position (message, pos_x, pos_y);
-	  clutter_actor_show (message);
-	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), message);
-	  clutter_actor_set_reactive (message, TRUE);
+	  ClutterActor* message_actor = tangle_texture_new (path1);
+	  clutter_actor_set_size (message_actor, 200, 100);
+	  clutter_actor_set_position (message_actor, pos_x, pos_y);
+	  clutter_actor_show (message_actor);
+	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), message_actor);
+	  clutter_actor_set_reactive (message_actor, TRUE);
 	  
 }
 
