@@ -781,9 +781,17 @@ gint gems_communication_process_connected()
 					{
 						/* CORRECT AMOUNT */
 						case sizeof(guint32):
-							//TODO check that length is in limits
 							//printf("gems_communication_process_list: read length: %d", ntohl(packetlength));
-							gems_connection_add_32(element,packetlength); // Add length
+							// Check that length is in limits
+							if(ntohl(packetlength) > (JAMMO_NETWORK_BUFFER_MAX_SIZE - sizeof(guint32) - sizeof(guint16)))
+							{
+								logmsg = g_strdup_printf("gems_communication_process_list: packet is too big (%u bytes), disconnecting.",ntohl(packetlength));
+								cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+								g_free(logmsg);
+								ph_c_connection_disconnect(element->connection);
+								cleanup_required = TRUE;
+							}
+							else gems_connection_add_32(element,packetlength); // Add length
 							break;
 						case 0:
 						case -1:
