@@ -94,7 +94,7 @@ gint gems_profile_manager_authenticate_user(const gchar* username, const gchar*
 			cem_add_to_log("Authentication - unknown state when loading profile ?",J_LOG_ERROR);
 			break;
 	}
-	if(!passworddata) printf("pass null\n");
+
 	// Create password from data
 	if((passwd = gems_security_create_password(passworddata,profilemanager_storage_get_password_salt(pm))) == NULL)
 	{
@@ -107,7 +107,11 @@ gint gems_profile_manager_authenticate_user(const gchar* username, const gchar*
 	if(!gems_security_init_security(passwd,profilemanager_storage_get_password_salt(pm)))
 	{
 		cem_add_to_log("Authentication methods not available, couldn't initialize security.", J_LOG_ERROR);
-		if(passwd != NULL) g_free(passwd);
+		if(passwd != NULL)
+		{
+			gems_guaranteed_memset(passwd,0,PASSLEN);
+			g_free(passwd);
+		}
 		gems_security_clear_security();
 		return LOGIN_CANNOT_INIT_SECURITY;
 	}
@@ -122,7 +126,11 @@ gint gems_profile_manager_authenticate_user(const gchar* username, const gchar*
 	if(!gems_security_verify_hash(pwhash,profilemanager_storage_get_password_hash(pm),SHA_HASH_LENGTH))
 	{
 		cem_add_to_log("Authentication failure: invalid password", J_LOG_ERROR);
-		if(passwd != NULL) g_free(passwd);
+		if(passwd != NULL)
+		{
+			gems_guaranteed_memset(passwd,0,PASSLEN);
+			g_free(passwd);
+		}
 		if(pwhash != NULL) g_free(pwhash);
 		gems_security_clear_security();
 		return LOGIN_INVALID_PASSWORD;
@@ -143,7 +151,11 @@ gint gems_profile_manager_authenticate_user(const gchar* username, const gchar*
 	if(!gems_security_verify_hash(decprofhash,profilemanager_storage_get_profile_hash(pm),SHA_HASH_LENGTH))
 	{
 		cem_add_to_log("Authentication failure: decrypted profile content differs from stored!", J_LOG_ERROR);
-		if(passwd != NULL) g_free(passwd);
+		if(passwd != NULL)
+		{
+			gems_guaranteed_memset(passwd,0,PASSLEN);
+			g_free(passwd);
+		}
 		if(pwhash != NULL) g_free(pwhash);
 		if(decrypted != NULL) g_free(decrypted);
 		if(decprofhash != NULL) g_free(decprofhash);
@@ -156,7 +168,11 @@ gint gems_profile_manager_authenticate_user(const gchar* username, const gchar*
 	if(!profilemanager_storage_deserialize_profile(pm,decrypted))
 	{
 		cem_add_to_log("Unable to set profile data, data is invalid.",J_LOG_ERROR);
-		if(passwd != NULL) g_free(passwd);
+		if(passwd != NULL)
+		{
+			gems_guaranteed_memset(passwd,0,PASSLEN);
+			g_free(passwd);
+		}
 		if(pwhash != NULL) g_free(pwhash);
 		if(decrypted != NULL) g_free(decrypted);
 		if(decprofhash != NULL) g_free(decprofhash);
@@ -167,7 +183,11 @@ gint gems_profile_manager_authenticate_user(const gchar* username, const gchar*
 	// Set to authenticated
 	profilemanager_set_authenticated(pm);
 	
-	if(passwd != NULL) g_free(passwd);
+	if(passwd != NULL)
+	{
+		gems_guaranteed_memset(passwd,0,PASSLEN);
+		g_free(passwd);
+	}
 	if(pwhash != NULL) g_free(pwhash);
 	if(decrypted != NULL) g_free(decrypted);
 	if(decprofhash != NULL) g_free(decprofhash);
