@@ -135,6 +135,7 @@ guchar* gems_security_create_password(const gchar* password_data, const guchar*
 	guchar* passwd = NULL;
 	
 	if(password_data == NULL || salt == NULL) return NULL;
+	if((strlen(password_data) + AES_SALT_LENGTH) > PASSLEN) return NULL;
 	
 	passwd = g_new0(guchar,sizeof(guchar)*PASSLEN);
 	g_memmove(&passwd[0],password_data,strlen(password_data));
@@ -216,8 +217,8 @@ gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, const
 	gchar* logmsg = NULL;
 	gboolean returnvalue = TRUE;
 	
-	memset(&key,0,32);
-	memset(&iv,0,32);
+	gems_guaranteed_memset(&key,0,32);
+	gems_guaranteed_memset(&iv,0,32);
 	
 	if(EVP_BytesToKey(EVP_aes_256_cbc(),EVP_sha256(), salt, keydata, keylength, AES_ROUNDS, key, iv) != 32)
 	{
@@ -247,6 +248,9 @@ gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, const
 		returnvalue =  FALSE;
 	}
 	
+	gems_guaranteed_memset(&key,0,32);
+	gems_guaranteed_memset(&iv,0,32);
+	
 	return returnvalue;
 }
 
