@@ -189,3 +189,14 @@ gboolean gems_check_profile_version(gchar* filename)
 	return rval;
 }
 
+/*
+ * Should guarantee that secret is erased from memory even with compiler optimizations 
+ * From http://www.dwheeler.com/secure-programs/Secure-Programs-HOWTO/protect-secrets.html
+ */
+void *gems_guaranteed_memset(void *data, gint value, guint length)
+{
+	volatile gchar *buffer = data;
+	while(length--) *buffer++ = value;
+	return data;
+}
+
